@@ -1,18 +1,18 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.12.0';
+$Git::Hooks::VERSION = '1.12.1';
 use 5.010;
 use strict;
 use warnings;
 use Carp;
 use Exporter qw/import/;
-use Data::Util qw(:all);
+use Sub::Util qw/subname/;
 use Path::Tiny;
 
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS); ## no critic (Modules::ProhibitAutomaticExportation)
 my (%Hooks, @PostHooks);
 
-BEGIN {                ## no critic (Subroutines::RequireArgUnpacking)
+BEGIN {                         ## no critic (RequireArgUnpacking)
     my @installers =
         qw/ APPLYPATCH_MSG PRE_APPLYPATCH POST_APPLYPATCH
             PRE_COMMIT PREPARE_COMMIT_MSG COMMIT_MSG
@@ -26,14 +26,12 @@ BEGIN {                ## no critic (Subroutines::RequireArgUnpacking)
     for my $installer (@installers) {
         my $hook = lc $installer;
         $hook =~ tr/_/-/;
-        install_subroutine(
-            __PACKAGE__,
-            $installer => sub (&) {
-                my ($foo) = @_;
-                my ($package) = get_code_info($foo);
-                $Hooks{$hook}{$foo} ||= [ $package, sub { $foo->(@_); } ];
-            }
-        );
+        no strict 'refs';       ## no critic (ProhibitNoStrict)
+        *{__PACKAGE__ . '::' . $installer} = sub (&) {
+            my ($foo) = @_;
+            my $subname = subname($foo);
+            $Hooks{$hook}{$subname} ||= sub { $foo->(@_); };
+        }
     }
 
     @EXPORT      = (@installers, 'run_hook');
@@ -611,8 +609,8 @@ sub run_hook {                  ## no critic (Subroutines::ProhibitExcessComplex
     _load_plugins($git);
 
     # Call every hook function installed by the hook scripts before.
-    foreach my $hook_def (values %{$Hooks{$hook_name}}) {
-        my ($package, $hook) = @$hook_def;
+    while (my ($subname, $hook) = each %{$Hooks{$hook_name}}) {
+        my ($package) = $subname =~ m/^(.+)::/;
         my $ok = eval { $hook->($git, @args) };
         if (defined $ok) {
             # Modern hooks return a boolean value indicating their success.
@@ -692,7 +690,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.12.0
+version 1.12.1
 
 =head1 SYNOPSIS
 
@@ -1682,7 +1680,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
