@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '1.12.0';
+$Git::Hooks::CheckCommit::VERSION = '1.12.1';
 use 5.010;
 use utf8;
 use strict;
@@ -10,7 +10,6 @@ use warnings;
 use Error ':try';
 use Git::Hooks qw/:DEFAULT :utils/;
 use Git::More::Message;
-use Data::Util qw(:check);
 use List::MoreUtils qw/any none/;
 
 my $PKG = __PACKAGE__;
@@ -235,7 +234,7 @@ sub code_errors {
                     next CODE;
                 }
             }
-            if (is_code_ref($code)) {
+            if (defined $code && ref $code && ref $code eq 'CODE') {
                 push @$codes, $code;
             } else {
                 $git->error($PKG, "option check-code must end with a code ref");
@@ -377,7 +376,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 1.12.0
+version 1.12.1
 
 =head1 DESCRIPTION
 
@@ -606,7 +605,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
