@@ -2,14 +2,13 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '1.12.0';
+$Git::Hooks::CheckJira::VERSION = '1.12.1';
 use 5.010;
 use utf8;
 use strict;
 use warnings;
 use Git::Hooks qw/:DEFAULT :utils/;
 use Path::Tiny;
-use Data::Util qw(:check);
 use List::MoreUtils qw/uniq/;
 
 my $PKG = __PACKAGE__;
@@ -134,7 +133,7 @@ sub check_codes {
                 and $git->error($PKG, "couldn't parse option check-code value", $@)
                     and next CODE;
         }
-        is_code_ref($code)
+        defined $code and ref $code and ref $code eq 'CODE'
             or $git->error($PKG, "option check-code must end with a code ref")
                 and next CODE;
         push @codes, $code;
@@ -265,7 +264,7 @@ sub _check_jira_keys {          ## no critic (ProhibitExcessComplexity)
         if (defined $ok) {
             ++$errors unless $ok;
         } elsif (length $@) {
-            $git->error($PKG, "error while evaluating check-code: $@");
+            $git->error($PKG, 'error while evaluating check-code', $@);
             ++$errors;
         }
     }
@@ -460,7 +459,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 1.12.0
+version 1.12.1
 
 =head1 DESCRIPTION
 
@@ -813,7 +812,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
