@@ -2,18 +2,33 @@
 
 package Git::Hooks::CheckStructure;
 # ABSTRACT: Git::Hooks plugin for ref/file structure validation
-$Git::Hooks::CheckStructure::VERSION = '1.12.0';
+$Git::Hooks::CheckStructure::VERSION = '1.12.1';
 use 5.010;
 use utf8;
 use strict;
 use warnings;
 use Git::Hooks qw/:DEFAULT :utils/;
-use Data::Util qw(:check);
 use Error qw(:try);
 
 my $PKG = __PACKAGE__;
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
 
+##########
+# Data validation utilities
+
+sub is_string {                 ## no critic (RequireArgUnpacking)
+    return defined $_[0] && ! ref $_[0] && length($_[0]);
+}
+
+sub is_integer {                ## no critic (RequireArgUnpacking)
+    return is_string(@_) && $_[0] !~ /\D/;
+}
+
+sub is_ref {
+    my ($name, $object) = @_;
+    return defined $object && ref $object && ref $object eq $name;
+}
+
 ##########
 
 sub get_structure {
@@ -60,7 +75,7 @@ sub check_array_structure {
                 }
             }
             # next
-        } elsif (is_rx($lhs)) {
+        } elsif (is_ref(Regexp => $lhs)) {
             if ($path->[0] =~ $lhs) {
                 return check_structure($rhs, $path);
             }
@@ -96,7 +111,7 @@ sub check_structure {
 
     @$path > 0 or die "$PKG(check_structure): Internal error!\n";
 
-    if (is_array_ref($structure)) {
+    if (is_ref(ARRAY => $structure)) {
         return check_array_structure($structure, $path);
     } elsif (is_string($structure)) {
         return check_string_structure($structure, $path);
@@ -202,7 +217,7 @@ Git::Hooks::CheckStructure - Git::Hooks plugin for ref/file structure validation
 
 =head1 VERSION
 
-version 1.12.0
+version 1.12.1
 
 =head1 DESCRIPTION
 
@@ -252,7 +267,7 @@ option:
 
     git config --add githooks.plugin CheckStructure
 
-=for Pod::Coverage check_added_files check_ref get_structure check_array_structure check_string_structure
+=for Pod::Coverage is_integer is_ref is_string check_added_files check_ref get_structure check_array_structure check_string_structure
 
 =head1 NAME
 
@@ -449,7 +464,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2016 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
